package lesenvonmailattributen;

/**
 * Title:        Lesen der Mail Attribute
 * Description:
 * Copyright:    Copyright (c) 2000
 * Company:      Joller-Voss GmbH
 * @author J.M.Joller
 * @version 1.0
 */

import javax.mail.*;
import javax.mail.internet.*;
import java.util.*;


public class AttributeClient {

  public static void main(String[] args) {

    if (args.length == 0) {
      System.err.println(
       "Usage: java AttributeClient protocol://username@host/foldername");
      return;
    }

    URLName server = new URLName(args[0]);

    try {

      Session session = Session.getDefaultInstance(new Properties(),
       new MailAuthenticator(server.getUsername()));

      // CVerbindungsaufbau, Folder ffnen
      Folder folder = session.getFolder(server);
      if (folder == null) {
        System.out.println("Folder " + server.getFile() + " nicht gefunden.");
        System.exit(1);
      }
      folder.open(Folder.READ_ONLY);

      // Get the messages from the server
      Message[] messages = folder.getMessages();
      for (int i = 0; i < messages.length; i++) {
        System.out.println("------------ Message " + (i+1)
         + " ------------");
        String from = InternetAddress.toString(messages[i].getFrom());
        if (from != null) System.out.println("From: " + from);
        String to = InternetAddress.toString(
         messages[i].getRecipients(Message.RecipientType.TO));
        if (to != null) System.out.println("To: " + to);
        String subject = messages[i].getSubject();
        if (subject != null) System.out.println("Subject: " + subject);
        Date sent = messages[i].getSentDate();
        if (sent != null) System.out.println("Sent: " + sent);

        System.out.println();
        // Attribute
        System.out.println("Die Nachricht ist ungefhr "
         + messages[i].getSize() + " Bytes lang.");
        System.out.println("Die Nachricht umfasst ungefhr "
         + messages[i].getLineCount() + " Zeilen.");
        String disposition = messages[i].getDisposition();
        if (disposition == null) ; // nichts
        else if (disposition.equals(Part.INLINE)) {
          System.out.println("Inline Anzeige");
        }
        else if (disposition.equals(Part.ATTACHMENT)) {
          System.out.println("Attachment");
          String fileName = messages[i].getFileName();
          if (fileName != null) {
            System.out.println("Dateinamen des Attachments "
            + fileName);
          }
        }
        String description = messages[i].getDescription();
        if (description != null) {
          System.out.println("Description der Nachricht "
           + description);
        }

      }

      // Verbindungsabbau
      // Meldungen bleiben auf dem Server
      folder.close(false);

    }
    catch (Exception e) {
      e.printStackTrace();
    }

    // GUI abschliessen
    // exit()
    System.exit(0);

  }

}
